@@ -1,14 +1,9 @@
 import numpy as np
-
-# from numba import njit
-# from numba.np.extensions import cross2d
-
 from physiocurve.pressure import foot
 
 
-# @njit
-def findPressureFull(values, samplerate):
-    feetidx = foot.findPressureFeet(values, samplerate)
+def find_pressure_full(values, samplerate):
+    feetidx = foot.find_pressure_feet(values, samplerate)
     diaidx, sysidx = find_dia_sys(values, samplerate, feetidx)
     dicidx = find_dicrotics(values, diaidx, sysidx)
     return [feetidx, diaidx, sysidx, dicidx]
@@ -41,8 +36,8 @@ def find_dia_sys(values, samplerate, feetidx):
 
 
 # @njit(parallel=True)
-def distance(p1, p2, p3):
-    return np.cross(p2 - p1, p3 - p1)  # / np.linalg.norm(p2 - p1)
+def distance(l1, l2, p):
+    return np.cross(l2 - l1, p - l1)  # / np.linalg.norm(l2 - l1)
 
 
 # @njit(parallel=True)
@@ -51,6 +46,9 @@ def find_dicrotics(values, diaidx, sysidx):
     for n, d in enumerate(diaidx):
         if d > sysidx[0]:
             break
+    else:
+        # No break condition -> no cycle
+        return np.empty(0, dtype=int)
     diaidx = diaidx[n:]
 
     nvalues = len(diaidx)
@@ -62,14 +60,18 @@ def find_dicrotics(values, diaidx, sysidx):
         p1 = np.array([0, zoi[0]])
         p2 = np.array([di - si, zoi[-1]])
 
-        partidx = np.arange(int(len(zoi) / 3))
-        partzoi = zoi[partidx]
-        p3 = np.vstack((partidx, partzoi)).T
+        # partidx = np.arange(int(len(zoi) / 3))
+        # partzoi = zoi[zoiidx]
+        # p3 = np.vstack((zoiidx, partzoi)).T
+        zoiidx = np.arange(len(zoi))
+        p3 = np.vstack((zoiidx, zoi)).T
 
         d = distance(p1, p2, p3)
         if not len(d):
             continue
         dics[i] = si + np.argmin(d)
+    # Remove zero values corresponding to not found dic
+    # return dics[dics.astype(bool)]
     return dics
 
 
@@ -86,7 +88,8 @@ def find_local_extreme(a, begin, end, windowsize, searchmax=False):
         fcomp = np.greater_equal
         curext = np.inf
     direction = np.sign(end - begin)
-    assert direction != 0
+    if direction == 0:
+        return a
 
     step = windowsize * direction
     nwindows = int((end - begin) / step)
@@ -101,6 +104,8 @@ def find_local_extreme(a, begin, end, windowsize, searchmax=False):
             newzoi = a[start:stop]
         else:
             newzoi = a[stop:start]
+        if not len(newzoi):
+            continue
         newext = fextr(newzoi)
         if fcomp(newext, curext):
             break  # Past local extreme
